@@ -18,7 +18,7 @@ from kxy.api import APIClient, upload_data, approx_opt_remaining_time
 # Cache old job ids to avoid being charged twice for the same job.
 EXPLANATION_JOB_IDS = {}
 
-def model_explanation(data_df, prediction_column, problem_type):
+def model_explanation(data_df, prediction_column, problem_type, snr='auto'):
 	"""
 	.. _model-explanation:
 	Analyzes the variables that a model relies on the most in a brute-force fashion.
@@ -70,19 +70,20 @@ def model_explanation(data_df, prediction_column, problem_type):
 	sys.stdout.write("[{:{}}] {:d}% ETA: {}".format("="*k+">", max_k, k, approx_opt_remaining_time(k)))
 	sys.stdout.flush()
 
-	file_identifier = upload_data(data_df)
-	if file_identifier:
-		job_id = EXPLANATION_JOB_IDS.get((file_identifier, prediction_column, problem_type), None)
+	file_name = upload_data(data_df)
+	if file_name:
+		job_id = EXPLANATION_JOB_IDS.get((file_name, prediction_column, problem_type), None)
 		if job_id:
 			api_response = APIClient.route(
 				path='/wk/variable-selection', method='POST', \
-				file_identifier=file_identifier, target_column=prediction_column, \
-				problem_type=problem_type, timestamp=int(time()), job_id=job_id)
+				file_name=file_name, target_column=prediction_column, \
+				problem_type=problem_type, timestamp=int(time()), job_id=job_id, \
+				snr=snr)
 		else:
 			api_response = APIClient.route(
 				path='/wk/variable-selection', method='POST', \
-				file_identifier=file_identifier, target_column=prediction_column, \
-				problem_type=problem_type, timestamp=int(time()))
+				file_name=file_name, target_column=prediction_column, \
+				problem_type=problem_type, timestamp=int(time()), snr=snr)
 
 		initial_time = time()
 		while api_response.status_code == requests.codes.ok and k < max_k:
@@ -99,7 +100,7 @@ def model_explanation(data_df, prediction_column, problem_type):
 					response = api_response.json()
 					if 'job_id' in response:
 						job_id = response['job_id']
-						EXPLANATION_JOB_IDS[(file_identifier, prediction_column, problem_type)] = job_id
+						EXPLANATION_JOB_IDS[(file_name, prediction_column, problem_type)] = job_id
 						sleep(2 if kp<5 else 10 if k < max_k-4 else 300)
 						kp += 1
 						k = kp//2
@@ -108,8 +109,9 @@ def model_explanation(data_df, prediction_column, problem_type):
 						# Note: it is important to pass the job_id to avoid being charged twice for the work.
 						api_response = APIClient.route(
 							path='/wk/variable-selection', method='POST', \
-							file_identifier=file_identifier, target_column=prediction_column, \
-							problem_type=problem_type, timestamp=int(time()), job_id=job_id)
+							file_name=file_name, target_column=prediction_column, \
+							problem_type=problem_type, timestamp=int(time()), job_id=job_id, \
+							snr=snr)
 					else:
 						duration = int(time()-initial_time)
 						duration = str(duration) + 's' if duration < 60 else str(duration//60) + 'min'
